@@ -41,6 +41,7 @@ enum connman_network_type {
 	CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN = 8,
 	CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN = 9,
 	CONNMAN_NETWORK_TYPE_HSO           = 23,
+	CONNMAN_NETWORK_TYPE_VENDOR        = 10000,
 };
 
 enum connman_network_protocol {
@@ -58,8 +59,6 @@ extern void connman_network_unref(struct connman_network *network);
 
 extern const char *connman_network_get_identifier(struct connman_network *network);
 
-extern void connman_network_set_path(struct connman_network *network,
-							const char *path);
 extern const char *connman_network_get_path(struct connman_network *network);
 extern void connman_network_set_index(struct connman_network *network,
 								int index);
@@ -68,8 +67,29 @@ extern int connman_network_get_index(struct connman_network *network);
 extern void connman_network_set_protocol(struct connman_network *network,
 					enum connman_network_protocol protocol);
 
+extern int connman_network_set_available(struct connman_network *network,
+						connman_bool_t available);
+extern connman_bool_t connman_network_get_available(struct connman_network *network);
 extern int connman_network_set_connected(struct connman_network *network,
 						connman_bool_t connected);
+extern int connman_network_set_remember(struct connman_network *network,
+						connman_bool_t remember);
+extern connman_bool_t connman_network_get_remember(struct connman_network *network);
+
+extern int connman_network_connect(struct connman_network *network);
+
+extern int connman_network_set_string(struct connman_network *network,
+					const char *key, const char *value);
+extern const char *connman_network_get_string(struct connman_network *network,
+							const char *key);
+extern int connman_network_set_uint8(struct connman_network *network,
+					const char *key, connman_uint8_t value);
+extern connman_uint8_t connman_network_get_uint8(struct connman_network *network,
+							const char *key);
+extern int connman_network_set_blob(struct connman_network *network,
+			const char *key, const void *data, unsigned int size);
+extern const void *connman_network_get_blob(struct connman_network *network,
+					const char *key, unsigned int *size);
 
 extern struct connman_device *connman_network_get_device(struct connman_network *network);
 
