@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2008  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2009  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -112,3 +112,8 @@ void __connman_log_cleanup(void)
 
 	closelog();
 }
+
+gboolean __connman_debug_enabled(void)
+{
+	return debug_enabled;
+}
