@@ -51,23 +51,29 @@ static void disconnect_callback(DBusConnection *conn, void *user_data)
 }
 
 static gchar *option_device = NULL;
+static gchar *option_plugin = NULL;
 static gboolean option_detach = TRUE;
-static gboolean option_selftest = FALSE;
 static gboolean option_compat = FALSE;
 static gboolean option_debug = FALSE;
+static gboolean option_selftest = FALSE;
+static gboolean option_version = FALSE;
 
 static GOptionEntry options[] = {
 	{ "device", 'i', 0, G_OPTION_ARG_STRING, &option_device,
 				"Specify network device/interface", "DEV" },
+	{ "plugin", 'p', 0, G_OPTION_ARG_STRING, &option_plugin,
+				"Specify plugins to load", "NAME" },
 	{ "nodaemon", 'n', G_OPTION_FLAG_REVERSE,
 				G_OPTION_ARG_NONE, &option_detach,
 				"Don't fork daemon to background" },
-	{ "selftest", 't', 0, G_OPTION_ARG_NONE, &option_selftest,
-				"Run self testing routines" },
 	{ "compat", 'c', 0, G_OPTION_ARG_NONE, &option_compat,
 				"Enable Network Manager compatibility" },
 	{ "debug", 'd', 0, G_OPTION_ARG_NONE, &option_debug,
 				"Enable debug information output" },
+	{ "selftest", 't', 0, G_OPTION_ARG_NONE, &option_selftest,
+				"Run self testing routines" },
+	{ "version", 'v', 0, G_OPTION_ARG_NONE, &option_version,
+				"Show version information and exit" },
 	{ NULL },
 };
 
@@ -98,6 +104,11 @@ int main(int argc, char *argv[])
 
 	g_option_context_free(context);
 
+	if (option_version == TRUE) {
+		printf("%s\n", VERSION);
+		exit(0);
+	}
+
 	if (option_detach == TRUE) {
 		if (daemon(0, 0)) {
 			perror("Can't start daemon");
@@ -163,11 +174,12 @@ int main(int argc, char *argv[])
 	__connman_rtnl_init();
 	__connman_udev_init();
 
-	__connman_plugin_init();
+	__connman_plugin_init(option_plugin);
 
 	__connman_element_start();
 
 	g_free(option_device);
+	g_free(option_plugin);
 
 	memset(&sa, 0, sizeof(sa));
 	sa.sa_handler = sig_term;
